@@ -282,16 +282,7 @@ mockVocabRef <- function(backend = "database") {
       overwrite = TRUE
     )
   })
-  cdm <- CDMConnector::cdm_from_con(db,
-    cdm_tables = tidyselect::all_of(c(
-      "concept",
-      "concept_relationship",
-      "concept_ancestor",
-      "concept_synonym",
-      "vocabulary",
-      "drug_strength"
-    ))
-  )
+  cdm <- CDMConnector::cdm_from_con(db)
   if (backend == "database") {
     return(cdm)
   }
